import { expect, describe, it, beforeEach, afterEach } from 'vitest';
import * as fs from 'fs';
import * as ejs from 'ejs';
import * as path from 'path';
import { generate } from './sync.js';
describe('generate function tests', () => {
    let fsMock, ejsMock, pathMock;
    beforeEach(() => {
        fsMock = vi.spyOn(fs, 'readFileSync').mockImplementation(() => 'mocked data');
        ejsMock = vi.spyOn(ejs, 'render').mockImplementation(() => 'mocked render');
        pathMock = vi.spyOn(path, 'resolve').mockImplementation(() => 'mocked path');
    });
    afterEach(() => {
        // Cleanup any mocks after each test
        fsMock.mockRestore();
        ejsMock.mockRestore();
        pathMock.mockRestore();
    });
    it('should generate interface definitions based on configurations', async () => {
        // Setup mock return values
        fs.readFileSync.mockReturnValueOnce('template content here...'); // ... do this for each file read
        await generate();
        // Expectations
        expect(fs.writeFileSync).toHaveBeenCalled(); // Check if files were written as expected
        // ... Add more expectations based on the generated content or other side effects
    });
    it('should not overwrite existing sync files', async () => {
        fs.existsSync.mockReturnValue(true); // Mock the existence of the file
        await generate();
        expect(fs.writeFileSync).not.toHaveBeenCalledWith(expect.stringMatching(/\.ts$/), expect.any(String)); // Ensure .ts files are not overwritten
    });
    it('should handle duplicated sync names with an error', async () => {
        // Mock configurations to have duplicated sync names
        // ...
        try {
            await generate();
        }
        catch (e) {
            expect(e.message).toMatch(/is duplicated/); // Check if the error message contains the expected text
        }
    });
    it('should generate files in parent directory when inParentDirectory is true', async () => {
        // ...
        await generate(false, true);
        // Check if files are being written to the parent directory
        expect(fs.writeFileSync).toHaveBeenCalledWith(expect.stringMatching(/^\.\//), expect.any(String));
    });
    // ... Add more tests based on different scenarios and edge cases
});
//# sourceMappingURL=sync.unit.test.js.map